==> kie-dmn-validation-999-20250203.023502-186-sources.jar: org/kie/dmn/validation/DMNv1_2/Rules50DE92E02AC146BFF16C6B66E2F495CC.java <==
package org.kie.dmn.validation.DMNv1_2;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.ImportDMNResolverUtil;
import org.kie.dmn.model.api.dmndi.*;
import org.kie.dmn.model.api.*;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import javax.xml.XMLConstants;
import static java.util.Collections.emptyMap;
import static org.kie.dmn.core.util.NamespaceUtil.getNamespaceAndName;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.doesDefinitionsContainIdForDMNEdge;

public class Rules50DE92E02AC146BFF16C6B66E2F495CC implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.dmn.validation.DMNv1_2";
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<org.kie.dmn.validation.MessageReporter> var_reporter = D.globalOf(org.kie.dmn.validation.MessageReporter.class,
                                                                                                                  "org.kie.dmn.validation.DMNv1_2",
                                                                                                                  "reporter");

    protected java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    @Override
    public java.util.List<org.drools.model.Rule> getRules() {
        return rules;
    }

    public java.util.List<org.drools.model.Rule> getRulesList() {
        return java.util.Arrays.asList(Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_DRGELEMENT__MISSING__DMNSHAPE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_TEXTANNOTATION__MISSING__DMNSHAPE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_INFORMATIONREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_KNOWLEDGEREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_AUTHORITYREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_ASSOCIATION__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNSHAPE__UNKNOWN__REF__WITHOUT__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNSHAPE__UNKNOWN__REF__WITH__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNEGDE__UNKNOWN__REF__WITHOUT__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNEGDE__UNKNOWN__REF__WITH__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_VARIABLE__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_PARAMETER__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_COLUMN__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p1(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p2(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p3(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p4());
    }

    java.util.List<org.drools.model.Rule> rules = getRulesList();

    @Override
    public java.util.List<org.drools.model.Query> getQueries() {
        return java.util.Collections.emptyList();
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Collections.emptyList();
    }

    {
        globals.add(var_reporter);
    }
}

==> kie-dmn-validation-999-20250415.023218-243-sources.jar: org/kie/dmn/validation/DMNv1_2/Rules50DE92E02AC146BFF16C6B66E2F495CC.java <==
package org.kie.dmn.validation.DMNv1_2;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNImportsUtil;
import org.kie.dmn.model.api.dmndi.*;
import org.kie.dmn.model.api.*;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import javax.xml.XMLConstants;
import static java.util.Collections.emptyMap;
import static org.kie.dmn.core.util.NamespaceUtil.getNamespaceAndName;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.doesDefinitionsContainIdForDMNEdge;

public class Rules50DE92E02AC146BFF16C6B66E2F495CC implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.dmn.validation.DMNv1_2";
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<org.kie.dmn.validation.MessageReporter> var_reporter = D.globalOf(org.kie.dmn.validation.MessageReporter.class,
                                                                                                                  "org.kie.dmn.validation.DMNv1_2",
                                                                                                                  "reporter");

    protected java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    @Override
    public java.util.List<org.drools.model.Rule> getRules() {
        return rules;
    }

    public java.util.List<org.drools.model.Rule> getRulesList() {
        return java.util.Arrays.asList(Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_DRGELEMENT__MISSING__DMNSHAPE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_TEXTANNOTATION__MISSING__DMNSHAPE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_INFORMATIONREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_KNOWLEDGEREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_AUTHORITYREQUIREMENT__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods0.rule_ASSOCIATION__MISSING__DMNEDGE(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNSHAPE__UNKNOWN__REF__WITHOUT__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNSHAPE__UNKNOWN__REF__WITH__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNEGDE__UNKNOWN__REF__WITHOUT__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_DMNEGDE__UNKNOWN__REF__WITH__IMPORT(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_VARIABLE__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods1.rule_PARAMETER__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_COLUMN__NOTYPEREF(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p1(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p2(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p3(),
                                       Rules50DE92E02AC146BFF16C6B66E2F495CCRuleMethods2.rule_TYPEREF__NOT__FEEL__NOT__DEF__p4());
    }

    java.util.List<org.drools.model.Rule> rules = getRulesList();

    @Override
    public java.util.List<org.drools.model.Query> getQueries() {
        return java.util.Collections.emptyList();
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Collections.emptyList();
    }

    {
        globals.add(var_reporter);
    }
}
